@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Grape
   module DSL
     module Headers
@@ -10,7 +12,7 @@ module Grape
           @header ||= {}
         end
       end
-      alias_method :headers, :header
+      alias headers header
     end
   end
 end
