@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'active_support/concern'
 
 module Grape
@@ -20,10 +22,10 @@ module Grape
           if new_format
             namespace_inheritable(:format, new_format.to_sym)
             # define the default error formatters
-            namespace_inheritable(:default_error_formatter, Grape::ErrorFormatter.formatter_for(new_format, {}))
+            namespace_inheritable(:default_error_formatter, Grape::ErrorFormatter.formatter_for(new_format, **{}))
             # define a single mime type
             mime_type = content_types[new_format.to_sym]
-            fail Grape::Exceptions::MissingMimeType.new(new_format) unless mime_type
+            raise Grape::Exceptions::MissingMimeType.new(new_format) unless mime_type
             namespace_stackable(:content_types, new_format.to_sym => mime_type)
           else
             namespace_inheritable(:format)
@@ -43,7 +45,7 @@ module Grape
         # Specify a default error formatter.
         def default_error_formatter(new_formatter_name = nil)
           if new_formatter_name
-            new_formatter = Grape::ErrorFormatter.formatter_for(new_formatter_name, {})
+            new_formatter = Grape::ErrorFormatter.formatter_for(new_formatter_name, **{})
             namespace_inheritable(:default_error_formatter, new_formatter)
           else
             namespace_inheritable(:default_error_formatter)
@@ -51,11 +53,11 @@ module Grape
         end
 
         def error_formatter(format, options)
-          if options.is_a?(Hash) && options.key?(:with)
-            formatter = options[:with]
-          else
-            formatter = options
-          end
+          formatter = if options.is_a?(Hash) && options.key?(:with)
+                        options[:with]
+                      else
+                        options
+                      end
 
           namespace_stackable(:error_formatters, format.to_sym => formatter)
         end
@@ -88,7 +90,7 @@ module Grape
         #       rescue_from CustomError
         #     end
         #
-        # @overload rescue_from(*exception_classes, options = {})
+        # @overload rescue_from(*exception_classes, **options)
         #   @param [Array] exception_classes A list of classes that you want to rescue, or
         #     the symbol :all to rescue from all exceptions.
         #   @param [Block] block Execution block to handle the given exception.
@@ -106,23 +108,26 @@ module Grape
 
           options = args.extract_options!
           if block_given? && options.key?(:with)
-            fail ArgumentError, 'both :with option and block cannot be passed'
+            raise ArgumentError, 'both :with option and block cannot be passed'
           end
           handler ||= extract_with(options)
 
           if args.include?(:all)
             namespace_inheritable(:rescue_all, true)
             namespace_inheritable :all_rescue_handler, handler
+          elsif args.include?(:grape_exceptions)
+            namespace_inheritable(:rescue_all, true)
+            namespace_inheritable(:rescue_grape_exceptions, true)
           else
             handler_type =
-                case options[:rescue_subclasses]
-                when nil, true
-                  :rescue_handlers
-                else
-                  :base_only_rescue_handlers
-                end
+              case options[:rescue_subclasses]
+              when nil, true
+                :rescue_handlers
+              else
+                :base_only_rescue_handlers
+              end
 
-            namespace_stackable handler_type, Hash[args.map { |arg| [arg, handler] }]
+            namespace_reverse_stackable handler_type, Hash[args.map { |arg| [arg, handler] }]
           end
 
           namespace_stackable(:rescue_options, options)
@@ -149,7 +154,7 @@ module Grape
         # @param model_class [Class] The model class that will be represented.
         # @option options [Class] :with The entity class that will represent the model.
         def represent(model_class, options)
-          fail Grape::Exceptions::InvalidWithOptionForRepresent.new unless options[:with] && options[:with].is_a?(Class)
+          raise Grape::Exceptions::InvalidWithOptionForRepresent.new unless options[:with] && options[:with].is_a?(Class)
           namespace_stackable(:representations, model_class => options[:with])
         end
 
@@ -157,10 +162,10 @@ module Grape
 
         def extract_with(options)
           return unless options.key?(:with)
-          with_option = options[:with]
+          with_option = options.delete(:with)
           return with_option if with_option.instance_of?(Proc)
-          return if with_option.instance_of?(Symbol) || with_option.instance_of?(String)
-          fail ArgumentError, "with: #{with_option.class}, expected Symbol, String or Proc"
+          return with_option.to_sym if with_option.instance_of?(Symbol) || with_option.instance_of?(String)
+          raise ArgumentError, "with: #{with_option.class}, expected Symbol, String or Proc"
         end
       end
     end
