@@ -1,8 +1,13 @@
+# frozen_string_literal: true
+
 require 'grape/exceptions/base'
 
 module Grape
   module Exceptions
     class ValidationErrors < Grape::Exceptions::Base
+      ERRORS_FORMAT_KEY = 'grape.errors.format'
+      DEFAULT_ERRORS_FORMAT = '%{attributes} %{message}'
+
       include Enumerable
 
       attr_reader :errors
@@ -34,23 +39,21 @@ module Grape
         end
       end
 
-      def to_json(**_opts)
+      def to_json(*_opts)
         as_json.to_json
       end
 
       def full_messages
-        map { |attributes, error| full_message(attributes, error) }.uniq
-      end
-
-      private
-
-      def full_message(attributes, error)
-        I18n.t(
-          'grape.errors.format'.to_sym,
-          default: '%{attributes} %{message}',
-          attributes: attributes.count == 1 ? translate_attribute(attributes.first) : translate_attributes(attributes),
-          message: error.message
-        )
+        messages = map do |attributes, error|
+          I18n.t(
+            ERRORS_FORMAT_KEY,
+            default: DEFAULT_ERRORS_FORMAT,
+            attributes: translate_attributes(attributes),
+            message: error.message
+          )
+        end
+        messages.uniq!
+        messages
       end
     end
   end
