@@ -8,15 +8,16 @@ module Grape
       include Helpers
 
       attr_reader :app, :env, :options
+
       TEXT_HTML = 'text/html'
 
       include Grape::DSL::Headers
 
       # @param [Rack Application] app The standard argument for a Rack middleware.
       # @param [Hash] options A hash of options, simply stored for use by subclasses.
-      def initialize(app, options = {})
+      def initialize(app, *options)
         @app = app
-        @options = default_options.merge(options)
+        @options = options.any? ? default_options.merge(options.shift) : default_options
         @app_response = nil
       end
 
