@@ -4,7 +4,7 @@ module Grape
   class Router
     # this could be an OpenStruct, but doesn't work in Ruby 2.3.0, see https://bugs.ruby-lang.org/issues/12251
     class AttributeTranslator
-      attr_reader :attributes, :request_method, :requirements
+      attr_reader :attributes
 
       ROUTE_ATTRIBUTES = %i[
         prefix
@@ -23,7 +23,7 @@ module Grape
 
       ROUTER_ATTRIBUTES = %i[pattern index].freeze
 
-      def initialize(attributes = {})
+      def initialize(**attributes)
         @attributes = attributes
       end
 
@@ -37,7 +37,7 @@ module Grape
         attributes
       end
 
-      def method_missing(method_name, *args) # rubocop:disable Style/MethodMissing
+      def method_missing(method_name, *args)
         if setter?(method_name[-1])
           attributes[method_name[0..-1]] = *args
         else
