@@ -39,7 +39,7 @@ module Grape
       end
 
       def configuration
-        @api.configuration.evaluate
+        @api.configuration.respond_to?(:evaluate) ? @api.configuration.evaluate : @api.configuration
       end
 
       # @return [Boolean] whether or not this entire scope needs to be
@@ -54,14 +54,16 @@ module Grape
       end
 
       def meets_dependency?(params, request_params)
+        return true unless @dependent_on
+
         if @parent.present? && !@parent.meets_dependency?(@parent.params(request_params), request_params)
           return false
         end
 
-        return true unless @dependent_on
         return params.any? { |param| meets_dependency?(param, request_params) } if params.is_a?(Array)
-        return false unless params.respond_to?(:with_indifferent_access)
-        params = params.with_indifferent_access
+
+        # params might be anything what looks like a hash, so it must implement a `key?` method
+        return false unless params.respond_to?(:key?)
 
         @dependent_on.each do |dependency|
           if dependency.is_a?(Hash)
