@@ -20,17 +20,7 @@ eager_load!
 # so it should be set to true here as well to reflect that.
 I18n.enforce_available_locales = true
 
-module Chunks
-  def read_chunks(body)
-    buffer = []
-    body.each { |chunk| buffer << chunk }
-
-    buffer
-  end
-end
-
 RSpec.configure do |config|
-  config.include Chunks
   config.include Rack::Test::Methods
   config.include Spec::Support::Helpers
   config.raise_errors_for_deprecations!
